# Realistic Username Generator

A simple python package to create usernames. You can generate a basic or advanced username using this package.

## Installation

To install, type the following command in the terminal:

```bash
pip install realistic-username-generator
```

## Features

Once installed, there are two functions you can use to create usernames:

- `gen_basic_username()` - Generates a _basic_ username, like **Slygamer**, **NeoCommander49**, **CrazyWizard293** etc.

- `gen_real_username()` - Generates a more _realistic_ username, like **ItzTitan**, **FusionWasTaken**, **SirViper** etc.

## Contribute

If you want to contribute to this project, feel free to make a pull request on GitHub!
